<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => 'Paragraf ajustat',
	'diff_para_deplace' => 'Paragraf desplaçat',
	'diff_para_supprime' => 'Paragraf suprimit',
	'diff_texte_ajoute' => 'Tèxt ajustat',
	'diff_texte_deplace' => 'Tèxt ajustat',
	'diff_texte_supprime' => 'Tèxt suprimit',

	// I
	'info_historique' => 'Revisions:',
	'info_historique_lien' => 'Afichar l’istoric de las modificacions',
	'info_historique_titre' => 'Seguiment de las revisions',

	// V
	'version_initiale' => 'Version iniciau',
];
